@@ -48,6 +48,10 @@ class ClBuilderProfileAction(Action):
          'method': 'Builder.check_build_run()'},
         {'name': 'check_chroot_run',
          'method': 'Builder.check_chroot_run()'},
+        {'name': 'allow_scan_binhost',
+         'method': 'Builder.setVariable("cl_builder_binhost_scan_set",'
+                   '"on",True)'
+         },
         {'name': 'migrate_repository',
          'method': 'Builder.migrateCacheRepository('
                    'cl_builder_profile_url,cl_builder_profile_branch,'
