@@ -178,8 +178,7 @@ class Wsdl(WsdlBase):
                     _("Update the Build"),
                     normal=('cl_builder_prepared_id',
                             'cl_builder_binhost_stable_set',
-                            'update.cl_update_binhost_recheck_set',
-                            ),
+                            'update.cl_update_binhost_recheck_set',),
                     expert=(
                         'update.cl_update_sync_only_set',
                         'update.cl_update_other_set',
@@ -198,9 +197,47 @@ class Wsdl(WsdlBase):
                         'cl_templates_locate',
                         'cl_verbose_set',
                         'cl_dispatch_conf'),
-                    hide=('cl_templates_locate',
-                          'cl_verbose_set',
-                          'cl_dispatch_conf'),
+                    hide=(
+                        'cl_builder_prepared_id',
+                        'cl_builder_binhost_stable_set',
+                        'update.cl_update_binhost_recheck_set',
+                        'update.cl_update_sync_only_set',
+                        'update.cl_update_other_set',
+                        'update.cl_update_pretend_set',
+                        'cl_builder_sync_rep',
+                        'update.cl_update_emergelist_set',
+                        'update.cl_update_check_rep_set',
+                        'update.cl_update_world',
+                        'update.cl_update_egencache_force',
+                        'update.cl_update_eixupdate_force',
+                        'cl_builder_rebuild_changed_set',
+                        'update.cl_update_skip_rb_set',
+                        'update.cl_update_onedepth_set',
+                        'update.cl_update_cleanpkg_set',
+                        'cl_builder_branch_data',
+                        'cl_templates_locate',
+                        'cl_verbose_set',
+                        'cl_builder_branch_data',
+                        'cl_dispatch_conf'),
+                    brief=(
+                        'cl_builder_prepared_id',
+                        'cl_builder_binhost_stable_set',
+                        'update.cl_update_binhost_recheck_set',
+                        'update.cl_update_sync_only_set',
+                        'update.cl_update_other_set',
+                        'update.cl_update_pretend_set',
+                        'cl_builder_sync_rep',
+                        'update.cl_update_emergelist_set',
+                        'update.cl_update_check_rep_set',
+                        'update.cl_update_world',
+                        'update.cl_update_egencache_force',
+                        'update.cl_update_eixupdate_force',
+                        'cl_builder_rebuild_changed_set',
+                        'update.cl_update_skip_rb_set',
+                        'update.cl_update_onedepth_set',
+                        'update.cl_update_cleanpkg_set',
+                        'cl_builder_brief_branch_data',
+                    ),
                     next_label=_("Next"))],
             'brief': {'next': __("Perform"),
                       'name': __("Update the Build")}
